# Обзор технологий

Подробный обзор технологий, лежащих в основе современных систем управления данными, от способов хранения до архитектур обработки.

Этот обзор структурирован как путеводитель по технологическому ландшафту: от самых базовых компонентов (хранение, вычислительные движки) к более сложным архитектурным паттернам (Lambda, Kappa).
